/**************************************
   Generic HID Class implementation
 -------------------------------------
 Created by David Guillen (davidgf.net)
   Have a look at microchip examples
      and the USB Complete book
 -------------------------------------
 The code is under the public domain
***************************************/

#ifndef __HID__H_
#define __HID__H_

#include "usb.h"

#define HID_REPORT_DESC_SIZE 44
#define HID_REPORT_SIZE       3

#define HID_IN_REPORT    0x01
#define HID_OUT_REPORT   0x02
#define HID_FEAT_REPORT  0x03

// HID Class specific requests
#define HID_GET_REPORT      0x01
#define HID_GET_IDLE        0x02
#define HID_GET_PROTOCOL    0x03
#define HID_SET_REPORT      0x09
#define HID_SET_IDLE        0x0A
#define HID_SET_PROTOCOL    0x0B

// The USB calls generic class functions, which actually are HID
#define ClassInitEndpoint HIDInitEndpoint
#define ProcessClassRequest ProcessHIDRequest
#define ClassOutNotify HIDOutNotify

void HIDInitEndpoint(void);
char ProcessHIDRequest(void);
void HIDOutNotify(void);

extern volatile unsigned char ep1_in_buffer[HID_REPORT_SIZE];
extern volatile unsigned char ep1_out_buffer[HID_REPORT_SIZE];

char GetInputReport(unsigned char reportID);
char GetFeatureReport(unsigned char reportID);
char SetupOutputReport(unsigned char reportID);
char SetupFeatureReport(unsigned char reportID);
void SetOutputReport(unsigned char reportID);
void SetFeatureReport(unsigned char reportID);


#endif

